@@ -8,6 +8,14 @@
 //! weight, easy to use, and that could conveniently search structs and
 //! collections in my binary. So, I made `indicium`.
 //!
+//! # What's New?
+//!
+//! * `0.3.0`: Added new search type `SearchType::Live` which is for "search as
+//! you type" interfaces. It is sort of a hybrid between `autocomplete` and
+//! `SearchType::And`. It will search using an (incomplete) string and return
+//! keys as the search results. Each resulting key can then be used to retrieve
+//! the full record from its collection to be rendered & displayed to the user.
+//!
 //! # Quick Start Guide
 //!
 //! For our **Quick Start Guide** example, we will be searching inside of the
@@ -245,5 +253,5 @@ pub mod simple;
 
 // Support for the popular `Select2` jQuery plug-in.
 
-// #[cfg(feature = "select2")]
-// pub mod select2;
\ No newline at end of file
+#[cfg(feature = "select2")]
+pub mod select2;
\ No newline at end of file
