@@ -1,10 +1,11 @@
 use crate::simple::SearchIndex;
 use std::cmp::Ord;
-use std::collections::BTreeSet;
+use std::collections::{BTreeSet, HashSet};
+use std::hash::Hash;
 
 // -----------------------------------------------------------------------------
 
-impl<K: Ord> SearchIndex<K> {
+impl<K: Hash + Ord> SearchIndex<K> {
 
     // -------------------------------------------------------------------------
     //
@@ -97,11 +98,11 @@ impl<K: Ord> SearchIndex<K> {
         if let Some(last_keyword) = keywords.pop() {
 
             // Perform `And` search for entire string without the last keyword:
-            let search_results: BTreeSet<&K> =
+            let search_results: HashSet<&K> =
                 self.internal_search_and(keywords.as_slice());
 
             // Get all autocompletions for the last keyword.
-            let autocompletions: BTreeSet<(&String, &BTreeSet<K>)> =
+            let autocompletions: Vec<(&String, &BTreeSet<K>)> =
                 self.internal_autocomplete_keyword(&last_keyword);
 
             // Intersect the autocompletions for the last keyword with the
