@@ -6,10 +6,11 @@ mod keyword;
 
 use crate::simple::{AutocompleteType, SearchIndex};
 use std::cmp::Ord;
+use std::hash::Hash;
 
 // -----------------------------------------------------------------------------
 
-impl<K: Ord> SearchIndex<K> {
+impl<K: Hash + Ord> SearchIndex<K> {
 
     // -------------------------------------------------------------------------
     //
