@@ -1,7 +1,7 @@
-mod and_search;
 mod autocomplete;
 mod indexable_keywords;
 mod search;
+mod search_and;
 mod string_keywords;
 
 // -----------------------------------------------------------------------------
