@@ -1,22 +1,26 @@
+// Directories:
 mod autocomplete;
 mod internal;
 mod search;
 
+// Methods:
 mod autocomplete_type;
 mod builder;
 mod default;
 mod deref;
 mod indexable;
-mod indexable_keywords;
 mod insert;
 mod new;
 mod remove;
 mod replace;
 mod search_index;
 mod search_type;
-mod string_keywords;
 mod tests;
 
+// For debug builds only:
+#[cfg(debug_assertions)]
+mod profile;
+
 // -----------------------------------------------------------------------------
 
 pub use crate::simple::autocomplete_type::AutocompleteType;
