@@ -1,14 +1,12 @@
 // -----------------------------------------------------------------------------
 //
-/// Indicium `simple` search provides three types of search. The search type
+/// Indicium `simple` search provides four types of search. The search type
 /// that should be used really depends on your use-case: the nature of the data,
-/// the intent of the user, and the size of your data set. I would suggest
-/// trying & testing both `And` and `Or` searches to see which one works better
-/// for you. See variant descriptions for more information.
+/// the intent of the user, and the size of your data set.
 ///
 /// Support for `and` and `or` keywords inside the search string is not
-/// currently planned for the `simple` search engine. The intent is to have a
-/// relatively simple search engine.
+/// currently planned for the `simple` search engine since the intent is to have
+/// a relatively simple implementation.
 ///
 /// For more information on the setting the search type in a `SearchIndex` type
 /// see: [`SearchIndexBuilder`] or [`SearchIndex::new()`].
@@ -23,8 +21,23 @@ pub enum SearchType {
     /// search type. It is good for compact interfaces, where records are very
     /// simple, and data-sets are quite small.
     ///
-    /// Probably best suited as a form widget.
+    /// Probably best suited in a form widget.
     Keyword,
+    /// `Live` search allows for "search as you type." It is a hybridization
+    /// of `autocomplete` and `search`. This method will effectively search
+    /// all of the autocompletion options and return the search results to the
+    /// caller.
+    ///
+    /// This search method accepts multiple keywords in the search string. The
+    /// logical conjuction for multiple keywords is `And`. For example, a search
+    /// of `this that` will only return records containing keywords both `this`
+    /// **and** `that`. In other words, _all_ keywords must be present in a
+    /// record for it to be returned as a result.
+    ///
+    /// Modern Internet browsers often have a similar "type as you search"
+    /// functionality in the address bar. _Spotify_ also has a cool
+    /// implementation of a similar feature.
+    Live,
     /// This search method accepts multiple keywords in the search string. The
     /// logical conjuction for multiple keywords is `And`. For example, a search
     /// of `this that` will only return records containing keywords both `this`
@@ -38,7 +51,7 @@ pub enum SearchType {
     /// records I don't want." It's likely a better choice for large collections
     /// because it uses less CPU resouces than `Or`.
     ///
-    /// Probably best suited as a filter widget.
+    /// Probably best suited in a filter widget.
     And,
     /// This search method accepts multiple keywords in the search string. The
     /// logical conjuction for multiple keywords is `Or`. For example, a search
@@ -56,6 +69,6 @@ pub enum SearchType {
     /// keywords, find a record I might want" which works well if there aren't
     /// too many records.
     ///
-    /// Probably best suited for a search screen.
+    /// Probably best suited for a search results screen.
     Or,
 } // SearchType
\ No newline at end of file
